Learn R Programming

reproducer (version 0.4.2)

CalculateTheoreticalEffectSizes: CalculateTheoreticalEffectSizes

Description

This function constructs the theoretical effect sizes and distribution statistics four (normal, lognormal, Laplace & gamma) given specific parameter values for the distributions

Usage

CalculateTheoreticalEffectSizes(mean, std, type = "n")

Value

dataframe containing the expected standardized effect size, mean, variance,skewness and kurtosis statistics for samples from the specifie distribution

Arguments

mean

The theoretical central location parameter for the distribution specified by the type parameter.

std

The theoretical spread parameter for the distribution specified by the type parameter.

type

String identifying the distribution, "n" for normal, "ln" for lognormal, "lap" for Laplace, "g" for Gamm

Author

Barbara Kitchenham and Lech Madeyski

Examples

Run this code
CalculateTheoreticalEffectSizes(mean=0, std=1, type="l")
# A tibble: 1 x 5
#   RawMean RawVariance RawEffectSize RawSkewness RawKurtosis
#                                   
# 1    1.65        4.67         0.763        6.18        88.5
CalculateTheoreticalEffectSizes(mean=0, std=1, type="n")
#A tibble: 1 x 5
#  RawMean RawVariance RawEffectSize RawSkewness RawKurtosis
#                                  
#1       0           1             0           0           3

Run the code above in your browser using DataLab