Learn R Programming

reproducer (version 0.1.2)

Madeyski15EISEJ.OpenProjects: Madeyski15EISEJ.OpenProjects data

Description

If you use this data set please cite: Marian Jureczko and Lech Madeyski, "Cross-Project Defect Prediciton: An Empirical Study," (under review), 2015.

Usage

Madeyski15EISEJ.OpenProjects

Arguments

source

http://madeyski.e-informatyka.pl/reproducible-research/

Details

This paper presents an analysis of 84 versions of industrial, open-source and academic projects. We have empirically evaluated whether those project types constitute separate classes of projects with regard to defect prediction. The predictions obtained from the models trained on the data from the open source projects were compared with the predictions from the other models (built on proprietary, i.e. industrial, student, open source, and not open source projects).

Examples

Run this code
Madeyski15EISEJ.OpenProjects

Run the code above in your browser using DataLab