Learn R Programming

reproducer (version 0.6.0)

MunzelBrunner02.PGI: Patient Global Impression (PGI) data from Munzel and Brunner (2002)

Description

The longitudinal ordinal data analysed in the worked example of Munzel and Brunner (2002, Table 2). The patient rated global impression (PGI) was recorded for 15 patients with panic disorder at baseline and after 4 weeks of a physical exercise therapy. The PGI score is ordered categorical. The data illustrate the exact paired rank test (pairedRankTest): the paper reports \(T_R = -186\), \(D^+ = 29\) and a two-sided exact p-value of 0.010.

Usage

MunzelBrunner02.PGI

Arguments

Format

A data frame with 15 rows and 3 columns:

patient

integer patient identifier (1-15).

baseline

integer PGI score at baseline.

week4

integer PGI score after 4 weeks of therapy.